Rev 6587: Fix various typos in docstrings. Rename 'buffer' to 'buf' since it's now a python builtin function. in file:///home/vila/src/bzr/cleanup/various/
Vincent Ladeuil
v.ladeuil+lp at free.fr
Fri Aug 9 15:09:23 UTC 2013
At file:///home/vila/src/bzr/cleanup/various/
------------------------------------------------------------
revno: 6587
revision-id: v.ladeuil+lp at free.fr-20130809150923-y71dusyorep0hbkt
parent: pqm at pqm.ubuntu.com-20130805125340-jx2zcpjthxvlaue6
committer: Vincent Ladeuil <v.ladeuil+lp at free.fr>
branch nick: various
timestamp: Fri 2013-08-09 17:09:23 +0200
message:
Fix various typos in docstrings. Rename 'buffer' to 'buf' since it's now a python builtin function.
-------------- next part --------------
=== modified file 'bzrlib/config.py'
--- a/bzrlib/filters/__init__.py 2012-08-02 11:28:25 +0000
+++ b/bzrlib/filters/__init__.py 2013-08-09 15:09:23 +0000
@@ -18,7 +18,7 @@
A filter consists of a read converter, write converter pair.
The content in the working tree is called the convenience format
-while the content actually stored in called the canonical format.
+while the content actually stored is called the canonical format.
The read converter produces canonical content from convenience
content while the writer goes the other way.
=== modified file 'bzrlib/tests/__init__.py'
--- a/bzrlib/tests/__init__.py 2013-06-24 12:03:12 +0000
+++ b/bzrlib/tests/__init__.py 2013-08-09 15:09:23 +0000
@@ -3792,7 +3792,7 @@
:return: (absents, duplicates) absents is a list containing the test found
in id_list but not in test_suite, duplicates is a list containing the
- test found multiple times in test_suite.
+ tests found multiple times in test_suite.
When using a prefined test id list, it may occurs that some tests do not
exist anymore or that some tests use the same id. This function warns the
@@ -4341,7 +4341,7 @@
"""Copy test and apply scenario to it.
:param test: A test to adapt.
- :param scenario: A tuple describing the scenarion.
+ :param scenario: A tuple describing the scenario.
The first element of the tuple is the new test id.
The second element is a dict containing attributes to set on the
test.
=== modified file 'bzrlib/transport/http/response.py'
--- a/bzrlib/transport/http/response.py 2013-05-24 23:45:55 +0000
+++ b/bzrlib/transport/http/response.py 2013-08-09 15:09:23 +0000
@@ -289,15 +289,15 @@
% (size, self._start, self._size))
# read data from file
- buffer = StringIO()
+ buf = StringIO()
limited = size
if self._size > 0:
# Don't read past the range definition
limited = self._start + self._size - self._pos
if size >= 0:
limited = min(limited, size)
- osutils.pumpfile(self._file, buffer, limited, self._max_read_size)
- data = buffer.getvalue()
+ osutils.pumpfile(self._file, buf, limited, self._max_read_size)
+ data = buf.getvalue()
# Update _pos respecting the data effectively read
self._pos += len(data)
More information about the bazaar-commits
mailing list
--- a/bzrlib/config.py 2012-09-19 09:15:29 +0000
+++ b/bzrlib/config.py 2013-08-09 15:09:23 +0000
@@ -2316,8 +2316,7 @@
:param help: a doc string to explain the option to the user.
:param from_unicode: a callable to convert the unicode string
- representing the option value in a store. This is not called for
- the default value.
+ representing the option value in a store or its default value.
:param invalid: the action to be taken when an invalid value is
encountered in a store. This is called only when from_unicode is
@@ -3400,9 +3399,9 @@
class LocationStore(LockableIniFileStore):
- """A config store for global options.
+ """A config store for options specific to a location.
- There is a single GlobalStore for a given process.
+ There is a single LocationStore for a given process.
"""
def __init__(self, possible_transports=None):
=== modified file 'bzrlib/filters/__init__.py'